@@ -101,20 +101,21 @@ class MessageCenter(object):
             module = self.__module_map.get(module_name, None)
             if module is None:
                 raise MessageCenterError.CannotFoundModule(module_name)
-            func = eval(f"module.{func_name}", {"module": module})
+            func = eval("module.%s" % func_name, {"module": module})
         elif target == "dobotlink":
             # TODO: 优化dobotlink的解释
             dobotlink = self.__module_map.get("dobotlink", None)
             if module is None:
                 raise MessageCenterError.CannotFoundModule("dobotlink")
-            module = eval(f"dobotlink.{module_name}", {"dobotlink": dobotlink})
-            func = eval(f"module.{func_name}", {"module": module})
+            module = eval("dobotlink.%s" % module_name,
+                          {"dobotlink": dobotlink})
+            func = eval("module.%s" % func_name, {"module": module})
         else:
             raise MessageCenterError.InvalidMethodFormat(method)
 
         return func
 
-    async def call(self, method: str, *args: Tuple[Any],
+    async def call(self, remote_address, method: str, *args: Tuple[Any],
                    **kwargs: Dict[str, Any]) -> None:
         """
         @Create Time:
@@ -135,6 +136,11 @@ class MessageCenter(object):
         """
 
         func = self.__method_parser(method)
+        if "rpc_context" in func.__code__.co_varnames:
+            kwargs["rpc_context"] = {
+                "client_ip": remote_address[0],
+                "client_port": remote_address[1]
+            }
         result = func(*args, **kwargs)
         if asyncio.iscoroutine(result):
             return await result
