@@ -43,11 +43,13 @@ class RPCClient(object):
 
     @property
     def remote_address(self):
-        return "%s:%d" % (self.__ws.remote_address[0], self.__ws.remote_address[1])
+        return "%s:%d" % (self.__ws.remote_address[0],
+                          self.__ws.remote_address[1])
 
     @property
     def local_address(self):
-        return "%s:%d" % (self.__ws.local_address[0], self.__ws.local_address[1])
+        return "%s:%d" % (self.__ws.local_address[0],
+                          self.__ws.local_address[1])
 
     def __pack_rpc(self,
                    rpc_id: int,
@@ -110,7 +112,9 @@ class RPCClient(object):
                     # 阻塞获取，不担心性能问题
                     ws_data = await self.__ws.recv()
                     loggers.get(LOGGER_NAME).debug(
-                        "C(%s) << S(%s):%s" % (str(self.local_address), str(self.remote_address), str(ws_data)))
+                        "C(%s) << S(%s):%s" %
+                        (str(self.local_address), str(
+                            self.remote_address), str(ws_data)))
                 except Exception as e:
                     loggers.get(LOGGER_NAME).error(e, exc_info=True)
                     if self.__cb_disconnected:
@@ -130,8 +134,8 @@ class RPCClient(object):
                             exchange["error"] = error
                             exchange["event"].set()
                     else:
-                        loggers.get(LOGGER_NAME).warning(
-                            "Invalid request:%s" % str(ws_data))
+                        loggers.get(LOGGER_NAME).warning("Invalid request:%s" %
+                                                         str(ws_data))
                 except Exception as e:
                     loggers.get(LOGGER_NAME).error(e, exc_info=True)
 
@@ -169,7 +173,8 @@ class RPCClient(object):
         }
 
         loggers.get(LOGGER_NAME).debug(
-            "C(%s) >> S(%s): %s" % (str(self.local_address), str(self.remote_address), str(payload)))
+            "C(%s) >> S(%s): %s" %
+            (str(self.local_address), str(self.remote_address), str(payload)))
         await self.__ws.send(json.dumps(payload))
 
         if cb_feedback:
@@ -216,8 +221,6 @@ class RPCClient(object):
             raise Exception("Had not connected!")
 
         rpc_packet = self.__pack_rpc(None, data, method)
-        loggers.get(LOGGER_NAME).debug(
-            "C(%s) >> S(%s): %s" % (str(self.local_address),
-                                    str(self.remote_address), str(rpc_packet))
-        )
+        loggers.get(LOGGER_NAME).debug("C(%s) >> S(%s): %s" % (str(
+            self.local_address), str(self.remote_address), str(rpc_packet)))
         await self.__ws.send(json.dumps(rpc_packet))
